@@ -4,6 +4,7 @@ import json
 
 from alipay.aop.api.constant.ParamConstants import *
 from alipay.aop.api.domain.TradeExtendParams import TradeExtendParams
+from alipay.aop.api.domain.SubsidyAmountParam import SubsidyAmountParam
 
 
 class AlipayCommerceMedicalPaymentCreateandpayModel(object):
@@ -19,11 +20,13 @@ class AlipayCommerceMedicalPaymentCreateandpayModel(object):
         self._merchant_name = None
         self._open_id = None
         self._org_no = None
+        self._other_amount = None
         self._out_trade_no = None
         self._pay_auth_no = None
         self._pay_order_id = None
         self._payment_city_code = None
         self._real_amount = None
+        self._subsidy_amount_params = None
         self._total_amount = None
         self._trade_no = None
 
@@ -101,6 +104,13 @@ class AlipayCommerceMedicalPaymentCreateandpayModel(object):
     def org_no(self, value):
         self._org_no = value
     @property
+    def other_amount(self):
+        return self._other_amount
+
+    @other_amount.setter
+    def other_amount(self, value):
+        self._other_amount = value
+    @property
     def out_trade_no(self):
         return self._out_trade_no
 
@@ -136,6 +146,19 @@ class AlipayCommerceMedicalPaymentCreateandpayModel(object):
     def real_amount(self, value):
         self._real_amount = value
     @property
+    def subsidy_amount_params(self):
+        return self._subsidy_amount_params
+
+    @subsidy_amount_params.setter
+    def subsidy_amount_params(self, value):
+        if isinstance(value, list):
+            self._subsidy_amount_params = list()
+            for i in value:
+                if isinstance(i, SubsidyAmountParam):
+                    self._subsidy_amount_params.append(i)
+                else:
+                    self._subsidy_amount_params.append(SubsidyAmountParam.from_alipay_dict(i))
+    @property
     def total_amount(self):
         return self._total_amount
 
@@ -203,6 +226,11 @@ class AlipayCommerceMedicalPaymentCreateandpayModel(object):
                 params['org_no'] = self.org_no.to_alipay_dict()
             else:
                 params['org_no'] = self.org_no
+        if self.other_amount:
+            if hasattr(self.other_amount, 'to_alipay_dict'):
+                params['other_amount'] = self.other_amount.to_alipay_dict()
+            else:
+                params['other_amount'] = self.other_amount
         if self.out_trade_no:
             if hasattr(self.out_trade_no, 'to_alipay_dict'):
                 params['out_trade_no'] = self.out_trade_no.to_alipay_dict()
@@ -228,6 +256,16 @@ class AlipayCommerceMedicalPaymentCreateandpayModel(object):
                 params['real_amount'] = self.real_amount.to_alipay_dict()
             else:
                 params['real_amount'] = self.real_amount
+        if self.subsidy_amount_params:
+            if isinstance(self.subsidy_amount_params, list):
+                for i in range(0, len(self.subsidy_amount_params)):
+                    element = self.subsidy_amount_params[i]
+                    if hasattr(element, 'to_alipay_dict'):
+                        self.subsidy_amount_params[i] = element.to_alipay_dict()
+            if hasattr(self.subsidy_amount_params, 'to_alipay_dict'):
+                params['subsidy_amount_params'] = self.subsidy_amount_params.to_alipay_dict()
+            else:
+                params['subsidy_amount_params'] = self.subsidy_amount_params
         if self.total_amount:
             if hasattr(self.total_amount, 'to_alipay_dict'):
                 params['total_amount'] = self.total_amount.to_alipay_dict()
@@ -265,6 +303,8 @@ class AlipayCommerceMedicalPaymentCreateandpayModel(object):
             o.open_id = d['open_id']
         if 'org_no' in d:
             o.org_no = d['org_no']
+        if 'other_amount' in d:
+            o.other_amount = d['other_amount']
         if 'out_trade_no' in d:
             o.out_trade_no = d['out_trade_no']
         if 'pay_auth_no' in d:
@@ -275,6 +315,8 @@ class AlipayCommerceMedicalPaymentCreateandpayModel(object):
             o.payment_city_code = d['payment_city_code']
         if 'real_amount' in d:
             o.real_amount = d['real_amount']
+        if 'subsidy_amount_params' in d:
+            o.subsidy_amount_params = d['subsidy_amount_params']
         if 'total_amount' in d:
             o.total_amount = d['total_amount']
         if 'trade_no' in d:
