@@ -9,6 +9,7 @@ class AlipayCommerceOperationItemListQueryModel(object):
 
     def __init__(self):
         self._pid = None
+        self._task_code = None
         self._user_id = None
 
     @property
@@ -19,6 +20,13 @@ class AlipayCommerceOperationItemListQueryModel(object):
     def pid(self, value):
         self._pid = value
     @property
+    def task_code(self):
+        return self._task_code
+
+    @task_code.setter
+    def task_code(self, value):
+        self._task_code = value
+    @property
     def user_id(self):
         return self._user_id
 
@@ -34,6 +42,11 @@ class AlipayCommerceOperationItemListQueryModel(object):
                 params['pid'] = self.pid.to_alipay_dict()
             else:
                 params['pid'] = self.pid
+        if self.task_code:
+            if hasattr(self.task_code, 'to_alipay_dict'):
+                params['task_code'] = self.task_code.to_alipay_dict()
+            else:
+                params['task_code'] = self.task_code
         if self.user_id:
             if hasattr(self.user_id, 'to_alipay_dict'):
                 params['user_id'] = self.user_id.to_alipay_dict()
@@ -48,6 +61,8 @@ class AlipayCommerceOperationItemListQueryModel(object):
         o = AlipayCommerceOperationItemListQueryModel()
         if 'pid' in d:
             o.pid = d['pid']
+        if 'task_code' in d:
+            o.task_code = d['task_code']
         if 'user_id' in d:
             o.user_id = d['user_id']
         return o
