@@ -8,10 +8,18 @@ from alipay.aop.api.constant.ParamConstants import *
 class AlipayCommerceOperationTimescardAuthorityDeleteModel(object):
 
     def __init__(self):
+        self._open_id = None
         self._scene_code = None
         self._user_id = None
 
     @property
+    def open_id(self):
+        return self._open_id
+
+    @open_id.setter
+    def open_id(self, value):
+        self._open_id = value
+    @property
     def scene_code(self):
         return self._scene_code
 
@@ -29,6 +37,11 @@ class AlipayCommerceOperationTimescardAuthorityDeleteModel(object):
 
     def to_alipay_dict(self):
         params = dict()
+        if self.open_id:
+            if hasattr(self.open_id, 'to_alipay_dict'):
+                params['open_id'] = self.open_id.to_alipay_dict()
+            else:
+                params['open_id'] = self.open_id
         if self.scene_code:
             if hasattr(self.scene_code, 'to_alipay_dict'):
                 params['scene_code'] = self.scene_code.to_alipay_dict()
@@ -46,6 +59,8 @@ class AlipayCommerceOperationTimescardAuthorityDeleteModel(object):
         if not d:
             return None
         o = AlipayCommerceOperationTimescardAuthorityDeleteModel()
+        if 'open_id' in d:
+            o.open_id = d['open_id']
         if 'scene_code' in d:
             o.scene_code = d['scene_code']
         if 'user_id' in d:
