@@ -12,6 +12,8 @@ class AlipayCommerceTransportAuthBindingGetModel(object):
         self._biz_cert_type = None
         self._cert_no = None
         self._cert_type = None
+        self._channel = None
+        self._open_id = None
         self._out_biz_no = None
         self._scene = None
         self._user_id = None
@@ -45,6 +47,20 @@ class AlipayCommerceTransportAuthBindingGetModel(object):
     def cert_type(self, value):
         self._cert_type = value
     @property
+    def channel(self):
+        return self._channel
+
+    @channel.setter
+    def channel(self, value):
+        self._channel = value
+    @property
+    def open_id(self):
+        return self._open_id
+
+    @open_id.setter
+    def open_id(self, value):
+        self._open_id = value
+    @property
     def out_biz_no(self):
         return self._out_biz_no
 
@@ -89,6 +105,16 @@ class AlipayCommerceTransportAuthBindingGetModel(object):
                 params['cert_type'] = self.cert_type.to_alipay_dict()
             else:
                 params['cert_type'] = self.cert_type
+        if self.channel:
+            if hasattr(self.channel, 'to_alipay_dict'):
+                params['channel'] = self.channel.to_alipay_dict()
+            else:
+                params['channel'] = self.channel
+        if self.open_id:
+            if hasattr(self.open_id, 'to_alipay_dict'):
+                params['open_id'] = self.open_id.to_alipay_dict()
+            else:
+                params['open_id'] = self.open_id
         if self.out_biz_no:
             if hasattr(self.out_biz_no, 'to_alipay_dict'):
                 params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
@@ -119,6 +145,10 @@ class AlipayCommerceTransportAuthBindingGetModel(object):
             o.cert_no = d['cert_no']
         if 'cert_type' in d:
             o.cert_type = d['cert_type']
+        if 'channel' in d:
+            o.channel = d['channel']
+        if 'open_id' in d:
+            o.open_id = d['open_id']
         if 'out_biz_no' in d:
             o.out_biz_no = d['out_biz_no']
         if 'scene' in d:
