@@ -9,6 +9,8 @@ class AlipayCommerceTransportEtcApplyorderCreateormodifyModel(object):
 
     def __init__(self):
         self._alipay_order_id = None
+        self._apply_scene = None
+        self._apply_sub_scene = None
         self._city_code = None
         self._mobile_no = None
         self._open_id = None
@@ -18,6 +20,7 @@ class AlipayCommerceTransportEtcApplyorderCreateormodifyModel(object):
         self._plate_color = None
         self._plate_no = None
         self._seller_id = None
+        self._spu_code = None
         self._user_id = None
         self._vi_license_apc = None
         self._vi_license_brand_model = None
@@ -40,6 +43,20 @@ class AlipayCommerceTransportEtcApplyorderCreateormodifyModel(object):
     def alipay_order_id(self, value):
         self._alipay_order_id = value
     @property
+    def apply_scene(self):
+        return self._apply_scene
+
+    @apply_scene.setter
+    def apply_scene(self, value):
+        self._apply_scene = value
+    @property
+    def apply_sub_scene(self):
+        return self._apply_sub_scene
+
+    @apply_sub_scene.setter
+    def apply_sub_scene(self, value):
+        self._apply_sub_scene = value
+    @property
     def city_code(self):
         return self._city_code
 
@@ -103,6 +120,13 @@ class AlipayCommerceTransportEtcApplyorderCreateormodifyModel(object):
     def seller_id(self, value):
         self._seller_id = value
     @property
+    def spu_code(self):
+        return self._spu_code
+
+    @spu_code.setter
+    def spu_code(self, value):
+        self._spu_code = value
+    @property
     def user_id(self):
         return self._user_id
 
@@ -202,6 +226,16 @@ class AlipayCommerceTransportEtcApplyorderCreateormodifyModel(object):
                 params['alipay_order_id'] = self.alipay_order_id.to_alipay_dict()
             else:
                 params['alipay_order_id'] = self.alipay_order_id
+        if self.apply_scene:
+            if hasattr(self.apply_scene, 'to_alipay_dict'):
+                params['apply_scene'] = self.apply_scene.to_alipay_dict()
+            else:
+                params['apply_scene'] = self.apply_scene
+        if self.apply_sub_scene:
+            if hasattr(self.apply_sub_scene, 'to_alipay_dict'):
+                params['apply_sub_scene'] = self.apply_sub_scene.to_alipay_dict()
+            else:
+                params['apply_sub_scene'] = self.apply_sub_scene
         if self.city_code:
             if hasattr(self.city_code, 'to_alipay_dict'):
                 params['city_code'] = self.city_code.to_alipay_dict()
@@ -247,6 +281,11 @@ class AlipayCommerceTransportEtcApplyorderCreateormodifyModel(object):
                 params['seller_id'] = self.seller_id.to_alipay_dict()
             else:
                 params['seller_id'] = self.seller_id
+        if self.spu_code:
+            if hasattr(self.spu_code, 'to_alipay_dict'):
+                params['spu_code'] = self.spu_code.to_alipay_dict()
+            else:
+                params['spu_code'] = self.spu_code
         if self.user_id:
             if hasattr(self.user_id, 'to_alipay_dict'):
                 params['user_id'] = self.user_id.to_alipay_dict()
@@ -321,6 +360,10 @@ class AlipayCommerceTransportEtcApplyorderCreateormodifyModel(object):
         o = AlipayCommerceTransportEtcApplyorderCreateormodifyModel()
         if 'alipay_order_id' in d:
             o.alipay_order_id = d['alipay_order_id']
+        if 'apply_scene' in d:
+            o.apply_scene = d['apply_scene']
+        if 'apply_sub_scene' in d:
+            o.apply_sub_scene = d['apply_sub_scene']
         if 'city_code' in d:
             o.city_code = d['city_code']
         if 'mobile_no' in d:
@@ -339,6 +382,8 @@ class AlipayCommerceTransportEtcApplyorderCreateormodifyModel(object):
             o.plate_no = d['plate_no']
         if 'seller_id' in d:
             o.seller_id = d['seller_id']
+        if 'spu_code' in d:
+            o.spu_code = d['spu_code']
         if 'user_id' in d:
             o.user_id = d['user_id']
         if 'vi_license_apc' in d:
