@@ -9,6 +9,7 @@ class AlipayEbppInstserviceContractdeductSignModel(object):
 
     def __init__(self):
         self._bill_key = None
+        self._open_id = None
         self._user_id = None
 
     @property
@@ -19,6 +20,13 @@ class AlipayEbppInstserviceContractdeductSignModel(object):
     def bill_key(self, value):
         self._bill_key = value
     @property
+    def open_id(self):
+        return self._open_id
+
+    @open_id.setter
+    def open_id(self, value):
+        self._open_id = value
+    @property
     def user_id(self):
         return self._user_id
 
@@ -34,6 +42,11 @@ class AlipayEbppInstserviceContractdeductSignModel(object):
                 params['bill_key'] = self.bill_key.to_alipay_dict()
             else:
                 params['bill_key'] = self.bill_key
+        if self.open_id:
+            if hasattr(self.open_id, 'to_alipay_dict'):
+                params['open_id'] = self.open_id.to_alipay_dict()
+            else:
+                params['open_id'] = self.open_id
         if self.user_id:
             if hasattr(self.user_id, 'to_alipay_dict'):
                 params['user_id'] = self.user_id.to_alipay_dict()
@@ -48,6 +61,8 @@ class AlipayEbppInstserviceContractdeductSignModel(object):
         o = AlipayEbppInstserviceContractdeductSignModel()
         if 'bill_key' in d:
             o.bill_key = d['bill_key']
+        if 'open_id' in d:
+            o.open_id = d['open_id']
         if 'user_id' in d:
             o.user_id = d['user_id']
         return o
