@@ -3,6 +3,7 @@
 import json
 
 from alipay.aop.api.constant.ParamConstants import *
+from alipay.aop.api.domain.AssetShareSourceInfo import AssetShareSourceInfo
 from alipay.aop.api.domain.ExpenseCtrRuleInfo import ExpenseCtrRuleInfo
 from alipay.aop.api.domain.StandardConditionInfo import StandardConditionInfo
 
@@ -12,12 +13,14 @@ class AlipayEbppInvoiceInstitutionExpenseruleCreateModel(object):
     def __init__(self):
         self._account_id = None
         self._agreement_no = None
+        self._asset_share_source_info = None
         self._consume_mode = None
         self._enterprise_id = None
         self._expense_ctrl_rule_info_list = None
         self._expense_type_sub_category = None
         self._institution_id = None
         self._open_rule_id = None
+        self._outer_source_id = None
         self._payment_policy = None
         self._standard_condition_info_list = None
         self._standard_desc = None
@@ -38,6 +41,16 @@ class AlipayEbppInvoiceInstitutionExpenseruleCreateModel(object):
     def agreement_no(self, value):
         self._agreement_no = value
     @property
+    def asset_share_source_info(self):
+        return self._asset_share_source_info
+
+    @asset_share_source_info.setter
+    def asset_share_source_info(self, value):
+        if isinstance(value, AssetShareSourceInfo):
+            self._asset_share_source_info = value
+        else:
+            self._asset_share_source_info = AssetShareSourceInfo.from_alipay_dict(value)
+    @property
     def consume_mode(self):
         return self._consume_mode
 
@@ -83,6 +96,13 @@ class AlipayEbppInvoiceInstitutionExpenseruleCreateModel(object):
     def open_rule_id(self, value):
         self._open_rule_id = value
     @property
+    def outer_source_id(self):
+        return self._outer_source_id
+
+    @outer_source_id.setter
+    def outer_source_id(self, value):
+        self._outer_source_id = value
+    @property
     def payment_policy(self):
         return self._payment_policy
 
@@ -130,6 +150,11 @@ class AlipayEbppInvoiceInstitutionExpenseruleCreateModel(object):
                 params['agreement_no'] = self.agreement_no.to_alipay_dict()
             else:
                 params['agreement_no'] = self.agreement_no
+        if self.asset_share_source_info:
+            if hasattr(self.asset_share_source_info, 'to_alipay_dict'):
+                params['asset_share_source_info'] = self.asset_share_source_info.to_alipay_dict()
+            else:
+                params['asset_share_source_info'] = self.asset_share_source_info
         if self.consume_mode:
             if hasattr(self.consume_mode, 'to_alipay_dict'):
                 params['consume_mode'] = self.consume_mode.to_alipay_dict()
@@ -160,6 +185,11 @@ class AlipayEbppInvoiceInstitutionExpenseruleCreateModel(object):
                 params['open_rule_id'] = self.open_rule_id.to_alipay_dict()
             else:
                 params['open_rule_id'] = self.open_rule_id
+        if self.outer_source_id:
+            if hasattr(self.outer_source_id, 'to_alipay_dict'):
+                params['outer_source_id'] = self.outer_source_id.to_alipay_dict()
+            else:
+                params['outer_source_id'] = self.outer_source_id
         if self.payment_policy:
             if hasattr(self.payment_policy, 'to_alipay_dict'):
                 params['payment_policy'] = self.payment_policy.to_alipay_dict()
@@ -196,6 +226,8 @@ class AlipayEbppInvoiceInstitutionExpenseruleCreateModel(object):
             o.account_id = d['account_id']
         if 'agreement_no' in d:
             o.agreement_no = d['agreement_no']
+        if 'asset_share_source_info' in d:
+            o.asset_share_source_info = d['asset_share_source_info']
         if 'consume_mode' in d:
             o.consume_mode = d['consume_mode']
         if 'enterprise_id' in d:
@@ -208,6 +240,8 @@ class AlipayEbppInvoiceInstitutionExpenseruleCreateModel(object):
             o.institution_id = d['institution_id']
         if 'open_rule_id' in d:
             o.open_rule_id = d['open_rule_id']
+        if 'outer_source_id' in d:
+            o.outer_source_id = d['outer_source_id']
         if 'payment_policy' in d:
             o.payment_policy = d['payment_policy']
         if 'standard_condition_info_list' in d:
