@@ -9,6 +9,7 @@ class AlipayEcoMycarUserAgreementQueryModel(object):
 
     def __init__(self):
         self._alipay_user_id = None
+        self._open_id = None
 
     @property
     def alipay_user_id(self):
@@ -17,6 +18,13 @@ class AlipayEcoMycarUserAgreementQueryModel(object):
     @alipay_user_id.setter
     def alipay_user_id(self, value):
         self._alipay_user_id = value
+    @property
+    def open_id(self):
+        return self._open_id
+
+    @open_id.setter
+    def open_id(self, value):
+        self._open_id = value
 
 
     def to_alipay_dict(self):
@@ -26,6 +34,11 @@ class AlipayEcoMycarUserAgreementQueryModel(object):
                 params['alipay_user_id'] = self.alipay_user_id.to_alipay_dict()
             else:
                 params['alipay_user_id'] = self.alipay_user_id
+        if self.open_id:
+            if hasattr(self.open_id, 'to_alipay_dict'):
+                params['open_id'] = self.open_id.to_alipay_dict()
+            else:
+                params['open_id'] = self.open_id
         return params
 
     @staticmethod
@@ -35,6 +48,8 @@ class AlipayEcoMycarUserAgreementQueryModel(object):
         o = AlipayEcoMycarUserAgreementQueryModel()
         if 'alipay_user_id' in d:
             o.alipay_user_id = d['alipay_user_id']
+        if 'open_id' in d:
+            o.open_id = d['open_id']
         return o
 
 
