@@ -15,6 +15,7 @@ class AlipayFundWalletDestroyModel(object):
         self._principal_open_id = None
         self._principal_type = None
         self._product_code = None
+        self._user_wallet_id = None
 
     @property
     def amount(self):
@@ -65,6 +66,13 @@ class AlipayFundWalletDestroyModel(object):
     @product_code.setter
     def product_code(self, value):
         self._product_code = value
+    @property
+    def user_wallet_id(self):
+        return self._user_wallet_id
+
+    @user_wallet_id.setter
+    def user_wallet_id(self, value):
+        self._user_wallet_id = value
 
 
     def to_alipay_dict(self):
@@ -104,6 +112,11 @@ class AlipayFundWalletDestroyModel(object):
                 params['product_code'] = self.product_code.to_alipay_dict()
             else:
                 params['product_code'] = self.product_code
+        if self.user_wallet_id:
+            if hasattr(self.user_wallet_id, 'to_alipay_dict'):
+                params['user_wallet_id'] = self.user_wallet_id.to_alipay_dict()
+            else:
+                params['user_wallet_id'] = self.user_wallet_id
         return params
 
     @staticmethod
@@ -125,6 +138,8 @@ class AlipayFundWalletDestroyModel(object):
             o.principal_type = d['principal_type']
         if 'product_code' in d:
             o.product_code = d['product_code']
+        if 'user_wallet_id' in d:
+            o.user_wallet_id = d['user_wallet_id']
         return o
 
 
