@@ -9,6 +9,7 @@ class AlipayMarketingActivityQueryModel(object):
 
     def __init__(self):
         self._activity_id = None
+        self._merchant_access_mode = None
         self._merchant_id = None
 
     @property
@@ -19,6 +20,13 @@ class AlipayMarketingActivityQueryModel(object):
     def activity_id(self, value):
         self._activity_id = value
     @property
+    def merchant_access_mode(self):
+        return self._merchant_access_mode
+
+    @merchant_access_mode.setter
+    def merchant_access_mode(self, value):
+        self._merchant_access_mode = value
+    @property
     def merchant_id(self):
         return self._merchant_id
 
@@ -34,6 +42,11 @@ class AlipayMarketingActivityQueryModel(object):
                 params['activity_id'] = self.activity_id.to_alipay_dict()
             else:
                 params['activity_id'] = self.activity_id
+        if self.merchant_access_mode:
+            if hasattr(self.merchant_access_mode, 'to_alipay_dict'):
+                params['merchant_access_mode'] = self.merchant_access_mode.to_alipay_dict()
+            else:
+                params['merchant_access_mode'] = self.merchant_access_mode
         if self.merchant_id:
             if hasattr(self.merchant_id, 'to_alipay_dict'):
                 params['merchant_id'] = self.merchant_id.to_alipay_dict()
@@ -48,6 +61,8 @@ class AlipayMarketingActivityQueryModel(object):
         o = AlipayMarketingActivityQueryModel()
         if 'activity_id' in d:
             o.activity_id = d['activity_id']
+        if 'merchant_access_mode' in d:
+            o.merchant_access_mode = d['merchant_access_mode']
         if 'merchant_id' in d:
             o.merchant_id = d['merchant_id']
         return o
