@@ -10,6 +10,7 @@ class AlipayMerchantIndirectAuthorderQuerystatusModel(object):
     def __init__(self):
         self._order_no = None
         self._out_biz_no = None
+        self._source = None
 
     @property
     def order_no(self):
@@ -25,6 +26,13 @@ class AlipayMerchantIndirectAuthorderQuerystatusModel(object):
     @out_biz_no.setter
     def out_biz_no(self, value):
         self._out_biz_no = value
+    @property
+    def source(self):
+        return self._source
+
+    @source.setter
+    def source(self, value):
+        self._source = value
 
 
     def to_alipay_dict(self):
@@ -39,6 +47,11 @@ class AlipayMerchantIndirectAuthorderQuerystatusModel(object):
                 params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
             else:
                 params['out_biz_no'] = self.out_biz_no
+        if self.source:
+            if hasattr(self.source, 'to_alipay_dict'):
+                params['source'] = self.source.to_alipay_dict()
+            else:
+                params['source'] = self.source
         return params
 
     @staticmethod
@@ -50,6 +63,8 @@ class AlipayMerchantIndirectAuthorderQuerystatusModel(object):
             o.order_no = d['order_no']
         if 'out_biz_no' in d:
             o.out_biz_no = d['out_biz_no']
+        if 'source' in d:
+            o.source = d['source']
         return o
 
 
