@@ -10,7 +10,9 @@ from alipay.aop.api.domain.WeightFloor import WeightFloor
 class AlipayMsaasMediarecogMmtcaftscvTransactionInitializeModel(object):
 
     def __init__(self):
+        self._device_identify_type = None
         self._goods_infos = None
+        self._open_id = None
         self._req_id = None
         self._scene = None
         self._terminal_id = None
@@ -19,6 +21,13 @@ class AlipayMsaasMediarecogMmtcaftscvTransactionInitializeModel(object):
         self._weight_template = None
 
     @property
+    def device_identify_type(self):
+        return self._device_identify_type
+
+    @device_identify_type.setter
+    def device_identify_type(self, value):
+        self._device_identify_type = value
+    @property
     def goods_infos(self):
         return self._goods_infos
 
@@ -32,6 +41,13 @@ class AlipayMsaasMediarecogMmtcaftscvTransactionInitializeModel(object):
                 else:
                     self._goods_infos.append(GoodInfo.from_alipay_dict(i))
     @property
+    def open_id(self):
+        return self._open_id
+
+    @open_id.setter
+    def open_id(self, value):
+        self._open_id = value
+    @property
     def req_id(self):
         return self._req_id
 
@@ -83,6 +99,11 @@ class AlipayMsaasMediarecogMmtcaftscvTransactionInitializeModel(object):
 
     def to_alipay_dict(self):
         params = dict()
+        if self.device_identify_type:
+            if hasattr(self.device_identify_type, 'to_alipay_dict'):
+                params['device_identify_type'] = self.device_identify_type.to_alipay_dict()
+            else:
+                params['device_identify_type'] = self.device_identify_type
         if self.goods_infos:
             if isinstance(self.goods_infos, list):
                 for i in range(0, len(self.goods_infos)):
@@ -93,6 +114,11 @@ class AlipayMsaasMediarecogMmtcaftscvTransactionInitializeModel(object):
                 params['goods_infos'] = self.goods_infos.to_alipay_dict()
             else:
                 params['goods_infos'] = self.goods_infos
+        if self.open_id:
+            if hasattr(self.open_id, 'to_alipay_dict'):
+                params['open_id'] = self.open_id.to_alipay_dict()
+            else:
+                params['open_id'] = self.open_id
         if self.req_id:
             if hasattr(self.req_id, 'to_alipay_dict'):
                 params['req_id'] = self.req_id.to_alipay_dict()
@@ -135,8 +161,12 @@ class AlipayMsaasMediarecogMmtcaftscvTransactionInitializeModel(object):
         if not d:
             return None
         o = AlipayMsaasMediarecogMmtcaftscvTransactionInitializeModel()
+        if 'device_identify_type' in d:
+            o.device_identify_type = d['device_identify_type']
         if 'goods_infos' in d:
             o.goods_infos = d['goods_infos']
+        if 'open_id' in d:
+            o.open_id = d['open_id']
         if 'req_id' in d:
             o.req_id = d['req_id']
         if 'scene' in d:
