@@ -9,6 +9,7 @@ class AlipayOpenAppServiceSchemaQueryModel(object):
 
     def __init__(self):
         self._category_id = None
+        self._template_type = None
 
     @property
     def category_id(self):
@@ -17,6 +18,13 @@ class AlipayOpenAppServiceSchemaQueryModel(object):
     @category_id.setter
     def category_id(self, value):
         self._category_id = value
+    @property
+    def template_type(self):
+        return self._template_type
+
+    @template_type.setter
+    def template_type(self, value):
+        self._template_type = value
 
 
     def to_alipay_dict(self):
@@ -26,6 +34,11 @@ class AlipayOpenAppServiceSchemaQueryModel(object):
                 params['category_id'] = self.category_id.to_alipay_dict()
             else:
                 params['category_id'] = self.category_id
+        if self.template_type:
+            if hasattr(self.template_type, 'to_alipay_dict'):
+                params['template_type'] = self.template_type.to_alipay_dict()
+            else:
+                params['template_type'] = self.template_type
         return params
 
     @staticmethod
@@ -35,6 +48,8 @@ class AlipayOpenAppServiceSchemaQueryModel(object):
         o = AlipayOpenAppServiceSchemaQueryModel()
         if 'category_id' in d:
             o.category_id = d['category_id']
+        if 'template_type' in d:
+            o.template_type = d['template_type']
         return o
 
 
