@@ -9,6 +9,7 @@ class AlipayOpenMiniVersionOfflineModel(object):
 
     def __init__(self):
         self._app_version = None
+        self._bundle_id = None
 
     @property
     def app_version(self):
@@ -17,6 +18,13 @@ class AlipayOpenMiniVersionOfflineModel(object):
     @app_version.setter
     def app_version(self, value):
         self._app_version = value
+    @property
+    def bundle_id(self):
+        return self._bundle_id
+
+    @bundle_id.setter
+    def bundle_id(self, value):
+        self._bundle_id = value
 
 
     def to_alipay_dict(self):
@@ -26,6 +34,11 @@ class AlipayOpenMiniVersionOfflineModel(object):
                 params['app_version'] = self.app_version.to_alipay_dict()
             else:
                 params['app_version'] = self.app_version
+        if self.bundle_id:
+            if hasattr(self.bundle_id, 'to_alipay_dict'):
+                params['bundle_id'] = self.bundle_id.to_alipay_dict()
+            else:
+                params['bundle_id'] = self.bundle_id
         return params
 
     @staticmethod
@@ -35,6 +48,8 @@ class AlipayOpenMiniVersionOfflineModel(object):
         o = AlipayOpenMiniVersionOfflineModel()
         if 'app_version' in d:
             o.app_version = d['app_version']
+        if 'bundle_id' in d:
+            o.bundle_id = d['bundle_id']
         return o
 
 
