@@ -8,10 +8,18 @@ from alipay.aop.api.constant.ParamConstants import *
 class AlipayOpenPublicSummaryQueryModel(object):
 
     def __init__(self):
+        self._open_id = None
         self._partner_id = None
         self._status = None
 
     @property
+    def open_id(self):
+        return self._open_id
+
+    @open_id.setter
+    def open_id(self, value):
+        self._open_id = value
+    @property
     def partner_id(self):
         return self._partner_id
 
@@ -29,6 +37,11 @@ class AlipayOpenPublicSummaryQueryModel(object):
 
     def to_alipay_dict(self):
         params = dict()
+        if self.open_id:
+            if hasattr(self.open_id, 'to_alipay_dict'):
+                params['open_id'] = self.open_id.to_alipay_dict()
+            else:
+                params['open_id'] = self.open_id
         if self.partner_id:
             if hasattr(self.partner_id, 'to_alipay_dict'):
                 params['partner_id'] = self.partner_id.to_alipay_dict()
@@ -46,6 +59,8 @@ class AlipayOpenPublicSummaryQueryModel(object):
         if not d:
             return None
         o = AlipayOpenPublicSummaryQueryModel()
+        if 'open_id' in d:
+            o.open_id = d['open_id']
         if 'partner_id' in d:
             o.partner_id = d['partner_id']
         if 'status' in d:
