@@ -16,6 +16,7 @@ class AlipayPayAppMarketingConsultModel(object):
         self._device_type = None
         self._encrypted_mobile = None
         self._goods_detail = None
+        self._history_alipay_trade_no = None
         self._merchant_user_id = None
         self._mobile = None
         self._need_query_anti_rank = None
@@ -23,6 +24,7 @@ class AlipayPayAppMarketingConsultModel(object):
         self._need_return_tag = None
         self._open_id = None
         self._out_trade_no = None
+        self._partner_id = None
         self._product_code = None
         self._promo_params = None
         self._seller_id = None
@@ -89,6 +91,13 @@ class AlipayPayAppMarketingConsultModel(object):
                 else:
                     self._goods_detail.append(GoodsDetail.from_alipay_dict(i))
     @property
+    def history_alipay_trade_no(self):
+        return self._history_alipay_trade_no
+
+    @history_alipay_trade_no.setter
+    def history_alipay_trade_no(self, value):
+        self._history_alipay_trade_no = value
+    @property
     def merchant_user_id(self):
         return self._merchant_user_id
 
@@ -138,6 +147,13 @@ class AlipayPayAppMarketingConsultModel(object):
     def out_trade_no(self, value):
         self._out_trade_no = value
     @property
+    def partner_id(self):
+        return self._partner_id
+
+    @partner_id.setter
+    def partner_id(self, value):
+        self._partner_id = value
+    @property
     def product_code(self):
         return self._product_code
 
@@ -228,6 +244,11 @@ class AlipayPayAppMarketingConsultModel(object):
                 params['goods_detail'] = self.goods_detail.to_alipay_dict()
             else:
                 params['goods_detail'] = self.goods_detail
+        if self.history_alipay_trade_no:
+            if hasattr(self.history_alipay_trade_no, 'to_alipay_dict'):
+                params['history_alipay_trade_no'] = self.history_alipay_trade_no.to_alipay_dict()
+            else:
+                params['history_alipay_trade_no'] = self.history_alipay_trade_no
         if self.merchant_user_id:
             if hasattr(self.merchant_user_id, 'to_alipay_dict'):
                 params['merchant_user_id'] = self.merchant_user_id.to_alipay_dict()
@@ -263,6 +284,11 @@ class AlipayPayAppMarketingConsultModel(object):
                 params['out_trade_no'] = self.out_trade_no.to_alipay_dict()
             else:
                 params['out_trade_no'] = self.out_trade_no
+        if self.partner_id:
+            if hasattr(self.partner_id, 'to_alipay_dict'):
+                params['partner_id'] = self.partner_id.to_alipay_dict()
+            else:
+                params['partner_id'] = self.partner_id
         if self.product_code:
             if hasattr(self.product_code, 'to_alipay_dict'):
                 params['product_code'] = self.product_code.to_alipay_dict()
@@ -314,6 +340,8 @@ class AlipayPayAppMarketingConsultModel(object):
             o.encrypted_mobile = d['encrypted_mobile']
         if 'goods_detail' in d:
             o.goods_detail = d['goods_detail']
+        if 'history_alipay_trade_no' in d:
+            o.history_alipay_trade_no = d['history_alipay_trade_no']
         if 'merchant_user_id' in d:
             o.merchant_user_id = d['merchant_user_id']
         if 'mobile' in d:
@@ -328,6 +356,8 @@ class AlipayPayAppMarketingConsultModel(object):
             o.open_id = d['open_id']
         if 'out_trade_no' in d:
             o.out_trade_no = d['out_trade_no']
+        if 'partner_id' in d:
+            o.partner_id = d['partner_id']
         if 'product_code' in d:
             o.product_code = d['product_code']
         if 'promo_params' in d:
