@@ -10,6 +10,7 @@ class AlipayUserDtbankcustChannelvoucherSendModel(object):
     def __init__(self):
         self._activity_id = None
         self._logon_id = None
+        self._open_id = None
         self._out_biz_no = None
         self._phone_id = None
         self._user_id = None
@@ -29,6 +30,13 @@ class AlipayUserDtbankcustChannelvoucherSendModel(object):
     def logon_id(self, value):
         self._logon_id = value
     @property
+    def open_id(self):
+        return self._open_id
+
+    @open_id.setter
+    def open_id(self, value):
+        self._open_id = value
+    @property
     def out_biz_no(self):
         return self._out_biz_no
 
@@ -63,6 +71,11 @@ class AlipayUserDtbankcustChannelvoucherSendModel(object):
                 params['logon_id'] = self.logon_id.to_alipay_dict()
             else:
                 params['logon_id'] = self.logon_id
+        if self.open_id:
+            if hasattr(self.open_id, 'to_alipay_dict'):
+                params['open_id'] = self.open_id.to_alipay_dict()
+            else:
+                params['open_id'] = self.open_id
         if self.out_biz_no:
             if hasattr(self.out_biz_no, 'to_alipay_dict'):
                 params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
@@ -89,6 +102,8 @@ class AlipayUserDtbankcustChannelvoucherSendModel(object):
             o.activity_id = d['activity_id']
         if 'logon_id' in d:
             o.logon_id = d['logon_id']
+        if 'open_id' in d:
+            o.open_id = d['open_id']
         if 'out_biz_no' in d:
             o.out_biz_no = d['out_biz_no']
         if 'phone_id' in d:
