@@ -3,6 +3,7 @@
 import json
 
 from alipay.aop.api.constant.ParamConstants import *
+from alipay.aop.api.domain.SettleCardInfo import SettleCardInfo
 from alipay.aop.api.domain.AddressInfo import AddressInfo
 from alipay.aop.api.domain.ShopBusinessTime import ShopBusinessTime
 from alipay.aop.api.domain.ContactInfo import ContactInfo
@@ -13,6 +14,7 @@ from alipay.aop.api.domain.IndustryQualificationInfo import IndustryQualificatio
 class AntMerchantExpandShopCreateModel(object):
 
     def __init__(self):
+        self._biz_cards = None
         self._brand_id = None
         self._business_address = None
         self._business_time = None
@@ -23,6 +25,7 @@ class AntMerchantExpandShopCreateModel(object):
         self._contact_infos = None
         self._contact_mobile = None
         self._contact_phone = None
+        self._cover = None
         self._ext_infos = None
         self._ip_role_id = None
         self._legal_cert_no = None
@@ -39,6 +42,19 @@ class AntMerchantExpandShopCreateModel(object):
         self._store_id = None
 
     @property
+    def biz_cards(self):
+        return self._biz_cards
+
+    @biz_cards.setter
+    def biz_cards(self, value):
+        if isinstance(value, list):
+            self._biz_cards = list()
+            for i in value:
+                if isinstance(i, SettleCardInfo):
+                    self._biz_cards.append(i)
+                else:
+                    self._biz_cards.append(SettleCardInfo.from_alipay_dict(i))
+    @property
     def brand_id(self):
         return self._brand_id
 
@@ -124,6 +140,13 @@ class AntMerchantExpandShopCreateModel(object):
     def contact_phone(self, value):
         self._contact_phone = value
     @property
+    def cover(self):
+        return self._cover
+
+    @cover.setter
+    def cover(self, value):
+        self._cover = value
+    @property
     def ext_infos(self):
         return self._ext_infos
 
@@ -240,6 +263,16 @@ class AntMerchantExpandShopCreateModel(object):
 
     def to_alipay_dict(self):
         params = dict()
+        if self.biz_cards:
+            if isinstance(self.biz_cards, list):
+                for i in range(0, len(self.biz_cards)):
+                    element = self.biz_cards[i]
+                    if hasattr(element, 'to_alipay_dict'):
+                        self.biz_cards[i] = element.to_alipay_dict()
+            if hasattr(self.biz_cards, 'to_alipay_dict'):
+                params['biz_cards'] = self.biz_cards.to_alipay_dict()
+            else:
+                params['biz_cards'] = self.biz_cards
         if self.brand_id:
             if hasattr(self.brand_id, 'to_alipay_dict'):
                 params['brand_id'] = self.brand_id.to_alipay_dict()
@@ -300,6 +333,11 @@ class AntMerchantExpandShopCreateModel(object):
                 params['contact_phone'] = self.contact_phone.to_alipay_dict()
             else:
                 params['contact_phone'] = self.contact_phone
+        if self.cover:
+            if hasattr(self.cover, 'to_alipay_dict'):
+                params['cover'] = self.cover.to_alipay_dict()
+            else:
+                params['cover'] = self.cover
         if self.ext_infos:
             if isinstance(self.ext_infos, list):
                 for i in range(0, len(self.ext_infos)):
@@ -392,6 +430,8 @@ class AntMerchantExpandShopCreateModel(object):
         if not d:
             return None
         o = AntMerchantExpandShopCreateModel()
+        if 'biz_cards' in d:
+            o.biz_cards = d['biz_cards']
         if 'brand_id' in d:
             o.brand_id = d['brand_id']
         if 'business_address' in d:
@@ -412,6 +452,8 @@ class AntMerchantExpandShopCreateModel(object):
             o.contact_mobile = d['contact_mobile']
         if 'contact_phone' in d:
             o.contact_phone = d['contact_phone']
+        if 'cover' in d:
+            o.cover = d['cover']
         if 'ext_infos' in d:
             o.ext_infos = d['ext_infos']
         if 'ip_role_id' in d:
