@@ -19,8 +19,12 @@ class AssetDeliveryItem(object):
         self._assign_item_id = None
         self._assign_out_order_id = None
         self._biz_line = None
+        self._biz_scene = None
         self._biz_tag = None
         self._biz_type = None
+        self._combination_batch_no = None
+        self._combination_count = None
+        self._combination_orders = None
         self._custom_clearance = None
         self._delivery_assign_order_item_id = None
         self._delivery_process_no = None
@@ -29,9 +33,11 @@ class AssetDeliveryItem(object):
         self._delivery_supplier_full_name = None
         self._delivery_supplier_id = None
         self._delivery_supplier_name = None
+        self._delivery_type = None
         self._ext_info = None
         self._from_address = None
         self._gmt_assign = None
+        self._is_combination_order = None
         self._item_id = None
         self._item_name = None
         self._logistics_info = None
@@ -42,6 +48,7 @@ class AssetDeliveryItem(object):
         self._out_biz_no = None
         self._parent_item_id = None
         self._print_data = None
+        self._priority = None
         self._produce_order_item_id = None
         self._record_type = None
         self._supplier_id = None
@@ -99,6 +106,13 @@ class AssetDeliveryItem(object):
     def biz_line(self, value):
         self._biz_line = value
     @property
+    def biz_scene(self):
+        return self._biz_scene
+
+    @biz_scene.setter
+    def biz_scene(self, value):
+        self._biz_scene = value
+    @property
     def biz_tag(self):
         return self._biz_tag
 
@@ -113,6 +127,30 @@ class AssetDeliveryItem(object):
     def biz_type(self, value):
         self._biz_type = value
     @property
+    def combination_batch_no(self):
+        return self._combination_batch_no
+
+    @combination_batch_no.setter
+    def combination_batch_no(self, value):
+        self._combination_batch_no = value
+    @property
+    def combination_count(self):
+        return self._combination_count
+
+    @combination_count.setter
+    def combination_count(self, value):
+        self._combination_count = value
+    @property
+    def combination_orders(self):
+        return self._combination_orders
+
+    @combination_orders.setter
+    def combination_orders(self, value):
+        if isinstance(value, list):
+            self._combination_orders = list()
+            for i in value:
+                self._combination_orders.append(i)
+    @property
     def custom_clearance(self):
         return self._custom_clearance
 
@@ -172,6 +210,13 @@ class AssetDeliveryItem(object):
     def delivery_supplier_name(self, value):
         self._delivery_supplier_name = value
     @property
+    def delivery_type(self):
+        return self._delivery_type
+
+    @delivery_type.setter
+    def delivery_type(self, value):
+        self._delivery_type = value
+    @property
     def ext_info(self):
         return self._ext_info
 
@@ -196,6 +241,13 @@ class AssetDeliveryItem(object):
     def gmt_assign(self, value):
         self._gmt_assign = value
     @property
+    def is_combination_order(self):
+        return self._is_combination_order
+
+    @is_combination_order.setter
+    def is_combination_order(self, value):
+        self._is_combination_order = value
+    @property
     def item_id(self):
         return self._item_id
 
@@ -269,6 +321,13 @@ class AssetDeliveryItem(object):
     def print_data(self, value):
         self._print_data = value
     @property
+    def priority(self):
+        return self._priority
+
+    @priority.setter
+    def priority(self, value):
+        self._priority = value
+    @property
     def produce_order_item_id(self):
         return self._produce_order_item_id
 
@@ -352,6 +411,11 @@ class AssetDeliveryItem(object):
                 params['biz_line'] = self.biz_line.to_alipay_dict()
             else:
                 params['biz_line'] = self.biz_line
+        if self.biz_scene:
+            if hasattr(self.biz_scene, 'to_alipay_dict'):
+                params['biz_scene'] = self.biz_scene.to_alipay_dict()
+            else:
+                params['biz_scene'] = self.biz_scene
         if self.biz_tag:
             if hasattr(self.biz_tag, 'to_alipay_dict'):
                 params['biz_tag'] = self.biz_tag.to_alipay_dict()
@@ -362,6 +426,26 @@ class AssetDeliveryItem(object):
                 params['biz_type'] = self.biz_type.to_alipay_dict()
             else:
                 params['biz_type'] = self.biz_type
+        if self.combination_batch_no:
+            if hasattr(self.combination_batch_no, 'to_alipay_dict'):
+                params['combination_batch_no'] = self.combination_batch_no.to_alipay_dict()
+            else:
+                params['combination_batch_no'] = self.combination_batch_no
+        if self.combination_count:
+            if hasattr(self.combination_count, 'to_alipay_dict'):
+                params['combination_count'] = self.combination_count.to_alipay_dict()
+            else:
+                params['combination_count'] = self.combination_count
+        if self.combination_orders:
+            if isinstance(self.combination_orders, list):
+                for i in range(0, len(self.combination_orders)):
+                    element = self.combination_orders[i]
+                    if hasattr(element, 'to_alipay_dict'):
+                        self.combination_orders[i] = element.to_alipay_dict()
+            if hasattr(self.combination_orders, 'to_alipay_dict'):
+                params['combination_orders'] = self.combination_orders.to_alipay_dict()
+            else:
+                params['combination_orders'] = self.combination_orders
         if self.custom_clearance:
             if hasattr(self.custom_clearance, 'to_alipay_dict'):
                 params['custom_clearance'] = self.custom_clearance.to_alipay_dict()
@@ -402,6 +486,11 @@ class AssetDeliveryItem(object):
                 params['delivery_supplier_name'] = self.delivery_supplier_name.to_alipay_dict()
             else:
                 params['delivery_supplier_name'] = self.delivery_supplier_name
+        if self.delivery_type:
+            if hasattr(self.delivery_type, 'to_alipay_dict'):
+                params['delivery_type'] = self.delivery_type.to_alipay_dict()
+            else:
+                params['delivery_type'] = self.delivery_type
         if self.ext_info:
             if hasattr(self.ext_info, 'to_alipay_dict'):
                 params['ext_info'] = self.ext_info.to_alipay_dict()
@@ -417,6 +506,11 @@ class AssetDeliveryItem(object):
                 params['gmt_assign'] = self.gmt_assign.to_alipay_dict()
             else:
                 params['gmt_assign'] = self.gmt_assign
+        if self.is_combination_order:
+            if hasattr(self.is_combination_order, 'to_alipay_dict'):
+                params['is_combination_order'] = self.is_combination_order.to_alipay_dict()
+            else:
+                params['is_combination_order'] = self.is_combination_order
         if self.item_id:
             if hasattr(self.item_id, 'to_alipay_dict'):
                 params['item_id'] = self.item_id.to_alipay_dict()
@@ -467,6 +561,11 @@ class AssetDeliveryItem(object):
                 params['print_data'] = self.print_data.to_alipay_dict()
             else:
                 params['print_data'] = self.print_data
+        if self.priority:
+            if hasattr(self.priority, 'to_alipay_dict'):
+                params['priority'] = self.priority.to_alipay_dict()
+            else:
+                params['priority'] = self.priority
         if self.produce_order_item_id:
             if hasattr(self.produce_order_item_id, 'to_alipay_dict'):
                 params['produce_order_item_id'] = self.produce_order_item_id.to_alipay_dict()
@@ -518,10 +617,18 @@ class AssetDeliveryItem(object):
             o.assign_out_order_id = d['assign_out_order_id']
         if 'biz_line' in d:
             o.biz_line = d['biz_line']
+        if 'biz_scene' in d:
+            o.biz_scene = d['biz_scene']
         if 'biz_tag' in d:
             o.biz_tag = d['biz_tag']
         if 'biz_type' in d:
             o.biz_type = d['biz_type']
+        if 'combination_batch_no' in d:
+            o.combination_batch_no = d['combination_batch_no']
+        if 'combination_count' in d:
+            o.combination_count = d['combination_count']
+        if 'combination_orders' in d:
+            o.combination_orders = d['combination_orders']
         if 'custom_clearance' in d:
             o.custom_clearance = d['custom_clearance']
         if 'delivery_assign_order_item_id' in d:
@@ -538,12 +645,16 @@ class AssetDeliveryItem(object):
             o.delivery_supplier_id = d['delivery_supplier_id']
         if 'delivery_supplier_name' in d:
             o.delivery_supplier_name = d['delivery_supplier_name']
+        if 'delivery_type' in d:
+            o.delivery_type = d['delivery_type']
         if 'ext_info' in d:
             o.ext_info = d['ext_info']
         if 'from_address' in d:
             o.from_address = d['from_address']
         if 'gmt_assign' in d:
             o.gmt_assign = d['gmt_assign']
+        if 'is_combination_order' in d:
+            o.is_combination_order = d['is_combination_order']
         if 'item_id' in d:
             o.item_id = d['item_id']
         if 'item_name' in d:
@@ -564,6 +675,8 @@ class AssetDeliveryItem(object):
             o.parent_item_id = d['parent_item_id']
         if 'print_data' in d:
             o.print_data = d['print_data']
+        if 'priority' in d:
+            o.priority = d['priority']
         if 'produce_order_item_id' in d:
             o.produce_order_item_id = d['produce_order_item_id']
         if 'record_type' in d:
