@@ -10,10 +10,13 @@ class EcConsumeInfo(object):
     def __init__(self):
         self._account_id = None
         self._agreement_peer_payer_id = None
+        self._benefit_amount = None
         self._biz_out_no = None
         self._category_name = None
         self._consume_amount = None
+        self._consume_biz_type = None
         self._consume_category = None
+        self._consume_fee_with_discount = None
         self._consume_memo = None
         self._consume_type = None
         self._employee_id = None
@@ -30,9 +33,13 @@ class EcConsumeInfo(object):
         self._merchant_id = None
         self._merchant_name = None
         self._open_id = None
+        self._opposite_full_name = None
         self._order_complete_label = None
         self._order_complete_time = None
         self._pay_no = None
+        self._payer_card_no = None
+        self._payer_logon_id = None
+        self._payer_name = None
         self._peer_pay_amount = None
         self._peer_payer_card_no = None
         self._peer_refund_amount = None
@@ -60,6 +67,13 @@ class EcConsumeInfo(object):
     def agreement_peer_payer_id(self, value):
         self._agreement_peer_payer_id = value
     @property
+    def benefit_amount(self):
+        return self._benefit_amount
+
+    @benefit_amount.setter
+    def benefit_amount(self, value):
+        self._benefit_amount = value
+    @property
     def biz_out_no(self):
         return self._biz_out_no
 
@@ -81,6 +95,13 @@ class EcConsumeInfo(object):
     def consume_amount(self, value):
         self._consume_amount = value
     @property
+    def consume_biz_type(self):
+        return self._consume_biz_type
+
+    @consume_biz_type.setter
+    def consume_biz_type(self, value):
+        self._consume_biz_type = value
+    @property
     def consume_category(self):
         return self._consume_category
 
@@ -88,6 +109,13 @@ class EcConsumeInfo(object):
     def consume_category(self, value):
         self._consume_category = value
     @property
+    def consume_fee_with_discount(self):
+        return self._consume_fee_with_discount
+
+    @consume_fee_with_discount.setter
+    def consume_fee_with_discount(self, value):
+        self._consume_fee_with_discount = value
+    @property
     def consume_memo(self):
         return self._consume_memo
 
@@ -200,6 +228,13 @@ class EcConsumeInfo(object):
     def open_id(self, value):
         self._open_id = value
     @property
+    def opposite_full_name(self):
+        return self._opposite_full_name
+
+    @opposite_full_name.setter
+    def opposite_full_name(self, value):
+        self._opposite_full_name = value
+    @property
     def order_complete_label(self):
         return self._order_complete_label
 
@@ -221,6 +256,27 @@ class EcConsumeInfo(object):
     def pay_no(self, value):
         self._pay_no = value
     @property
+    def payer_card_no(self):
+        return self._payer_card_no
+
+    @payer_card_no.setter
+    def payer_card_no(self, value):
+        self._payer_card_no = value
+    @property
+    def payer_logon_id(self):
+        return self._payer_logon_id
+
+    @payer_logon_id.setter
+    def payer_logon_id(self, value):
+        self._payer_logon_id = value
+    @property
+    def payer_name(self):
+        return self._payer_name
+
+    @payer_name.setter
+    def payer_name(self, value):
+        self._payer_name = value
+    @property
     def peer_pay_amount(self):
         return self._peer_pay_amount
 
@@ -311,6 +367,11 @@ class EcConsumeInfo(object):
                 params['agreement_peer_payer_id'] = self.agreement_peer_payer_id.to_alipay_dict()
             else:
                 params['agreement_peer_payer_id'] = self.agreement_peer_payer_id
+        if self.benefit_amount:
+            if hasattr(self.benefit_amount, 'to_alipay_dict'):
+                params['benefit_amount'] = self.benefit_amount.to_alipay_dict()
+            else:
+                params['benefit_amount'] = self.benefit_amount
         if self.biz_out_no:
             if hasattr(self.biz_out_no, 'to_alipay_dict'):
                 params['biz_out_no'] = self.biz_out_no.to_alipay_dict()
@@ -326,11 +387,21 @@ class EcConsumeInfo(object):
                 params['consume_amount'] = self.consume_amount.to_alipay_dict()
             else:
                 params['consume_amount'] = self.consume_amount
+        if self.consume_biz_type:
+            if hasattr(self.consume_biz_type, 'to_alipay_dict'):
+                params['consume_biz_type'] = self.consume_biz_type.to_alipay_dict()
+            else:
+                params['consume_biz_type'] = self.consume_biz_type
         if self.consume_category:
             if hasattr(self.consume_category, 'to_alipay_dict'):
                 params['consume_category'] = self.consume_category.to_alipay_dict()
             else:
                 params['consume_category'] = self.consume_category
+        if self.consume_fee_with_discount:
+            if hasattr(self.consume_fee_with_discount, 'to_alipay_dict'):
+                params['consume_fee_with_discount'] = self.consume_fee_with_discount.to_alipay_dict()
+            else:
+                params['consume_fee_with_discount'] = self.consume_fee_with_discount
         if self.consume_memo:
             if hasattr(self.consume_memo, 'to_alipay_dict'):
                 params['consume_memo'] = self.consume_memo.to_alipay_dict()
@@ -411,6 +482,11 @@ class EcConsumeInfo(object):
                 params['open_id'] = self.open_id.to_alipay_dict()
             else:
                 params['open_id'] = self.open_id
+        if self.opposite_full_name:
+            if hasattr(self.opposite_full_name, 'to_alipay_dict'):
+                params['opposite_full_name'] = self.opposite_full_name.to_alipay_dict()
+            else:
+                params['opposite_full_name'] = self.opposite_full_name
         if self.order_complete_label:
             if hasattr(self.order_complete_label, 'to_alipay_dict'):
                 params['order_complete_label'] = self.order_complete_label.to_alipay_dict()
@@ -426,6 +502,21 @@ class EcConsumeInfo(object):
                 params['pay_no'] = self.pay_no.to_alipay_dict()
             else:
                 params['pay_no'] = self.pay_no
+        if self.payer_card_no:
+            if hasattr(self.payer_card_no, 'to_alipay_dict'):
+                params['payer_card_no'] = self.payer_card_no.to_alipay_dict()
+            else:
+                params['payer_card_no'] = self.payer_card_no
+        if self.payer_logon_id:
+            if hasattr(self.payer_logon_id, 'to_alipay_dict'):
+                params['payer_logon_id'] = self.payer_logon_id.to_alipay_dict()
+            else:
+                params['payer_logon_id'] = self.payer_logon_id
+        if self.payer_name:
+            if hasattr(self.payer_name, 'to_alipay_dict'):
+                params['payer_name'] = self.payer_name.to_alipay_dict()
+            else:
+                params['payer_name'] = self.payer_name
         if self.peer_pay_amount:
             if hasattr(self.peer_pay_amount, 'to_alipay_dict'):
                 params['peer_pay_amount'] = self.peer_pay_amount.to_alipay_dict()
@@ -492,14 +583,20 @@ class EcConsumeInfo(object):
             o.account_id = d['account_id']
         if 'agreement_peer_payer_id' in d:
             o.agreement_peer_payer_id = d['agreement_peer_payer_id']
+        if 'benefit_amount' in d:
+            o.benefit_amount = d['benefit_amount']
         if 'biz_out_no' in d:
             o.biz_out_no = d['biz_out_no']
         if 'category_name' in d:
             o.category_name = d['category_name']
         if 'consume_amount' in d:
             o.consume_amount = d['consume_amount']
+        if 'consume_biz_type' in d:
+            o.consume_biz_type = d['consume_biz_type']
         if 'consume_category' in d:
             o.consume_category = d['consume_category']
+        if 'consume_fee_with_discount' in d:
+            o.consume_fee_with_discount = d['consume_fee_with_discount']
         if 'consume_memo' in d:
             o.consume_memo = d['consume_memo']
         if 'consume_type' in d:
@@ -532,12 +629,20 @@ class EcConsumeInfo(object):
             o.merchant_name = d['merchant_name']
         if 'open_id' in d:
             o.open_id = d['open_id']
+        if 'opposite_full_name' in d:
+            o.opposite_full_name = d['opposite_full_name']
         if 'order_complete_label' in d:
             o.order_complete_label = d['order_complete_label']
         if 'order_complete_time' in d:
             o.order_complete_time = d['order_complete_time']
         if 'pay_no' in d:
             o.pay_no = d['pay_no']
+        if 'payer_card_no' in d:
+            o.payer_card_no = d['payer_card_no']
+        if 'payer_logon_id' in d:
+            o.payer_logon_id = d['payer_logon_id']
+        if 'payer_name' in d:
+            o.payer_name = d['payer_name']
         if 'peer_pay_amount' in d:
             o.peer_pay_amount = d['peer_pay_amount']
         if 'peer_payer_card_no' in d:
