@@ -13,6 +13,7 @@ class HealthDrugCatalogueItem(object):
         self._drug_classification = None
         self._drug_type = None
         self._general_name = None
+        self._image = None
         self._inventory = None
         self._item_id = None
         self._item_name = None
@@ -20,7 +21,9 @@ class HealthDrugCatalogueItem(object):
         self._max_purchase_quantity = None
         self._min_purchase_quantity = None
         self._national_medicine_permission_no = None
+        self._not_purchase_reason_desc = None
         self._price = None
+        self._price_level = None
         self._specifications = None
         self._support_emergency_delivery = None
         self._usage_dosage = None
@@ -61,6 +64,13 @@ class HealthDrugCatalogueItem(object):
     def general_name(self, value):
         self._general_name = value
     @property
+    def image(self):
+        return self._image
+
+    @image.setter
+    def image(self, value):
+        self._image = value
+    @property
     def inventory(self):
         return self._inventory
 
@@ -110,6 +120,13 @@ class HealthDrugCatalogueItem(object):
     def national_medicine_permission_no(self, value):
         self._national_medicine_permission_no = value
     @property
+    def not_purchase_reason_desc(self):
+        return self._not_purchase_reason_desc
+
+    @not_purchase_reason_desc.setter
+    def not_purchase_reason_desc(self, value):
+        self._not_purchase_reason_desc = value
+    @property
     def price(self):
         return self._price
 
@@ -117,6 +134,13 @@ class HealthDrugCatalogueItem(object):
     def price(self, value):
         self._price = value
     @property
+    def price_level(self):
+        return self._price_level
+
+    @price_level.setter
+    def price_level(self, value):
+        self._price_level = value
+    @property
     def specifications(self):
         return self._specifications
 
@@ -166,6 +190,11 @@ class HealthDrugCatalogueItem(object):
                 params['general_name'] = self.general_name.to_alipay_dict()
             else:
                 params['general_name'] = self.general_name
+        if self.image:
+            if hasattr(self.image, 'to_alipay_dict'):
+                params['image'] = self.image.to_alipay_dict()
+            else:
+                params['image'] = self.image
         if self.inventory:
             if hasattr(self.inventory, 'to_alipay_dict'):
                 params['inventory'] = self.inventory.to_alipay_dict()
@@ -201,11 +230,21 @@ class HealthDrugCatalogueItem(object):
                 params['national_medicine_permission_no'] = self.national_medicine_permission_no.to_alipay_dict()
             else:
                 params['national_medicine_permission_no'] = self.national_medicine_permission_no
+        if self.not_purchase_reason_desc:
+            if hasattr(self.not_purchase_reason_desc, 'to_alipay_dict'):
+                params['not_purchase_reason_desc'] = self.not_purchase_reason_desc.to_alipay_dict()
+            else:
+                params['not_purchase_reason_desc'] = self.not_purchase_reason_desc
         if self.price:
             if hasattr(self.price, 'to_alipay_dict'):
                 params['price'] = self.price.to_alipay_dict()
             else:
                 params['price'] = self.price
+        if self.price_level:
+            if hasattr(self.price_level, 'to_alipay_dict'):
+                params['price_level'] = self.price_level.to_alipay_dict()
+            else:
+                params['price_level'] = self.price_level
         if self.specifications:
             if hasattr(self.specifications, 'to_alipay_dict'):
                 params['specifications'] = self.specifications.to_alipay_dict()
@@ -238,6 +277,8 @@ class HealthDrugCatalogueItem(object):
             o.drug_type = d['drug_type']
         if 'general_name' in d:
             o.general_name = d['general_name']
+        if 'image' in d:
+            o.image = d['image']
         if 'inventory' in d:
             o.inventory = d['inventory']
         if 'item_id' in d:
@@ -252,8 +293,12 @@ class HealthDrugCatalogueItem(object):
             o.min_purchase_quantity = d['min_purchase_quantity']
         if 'national_medicine_permission_no' in d:
             o.national_medicine_permission_no = d['national_medicine_permission_no']
+        if 'not_purchase_reason_desc' in d:
+            o.not_purchase_reason_desc = d['not_purchase_reason_desc']
         if 'price' in d:
             o.price = d['price']
+        if 'price_level' in d:
+            o.price_level = d['price_level']
         if 'specifications' in d:
             o.specifications = d['specifications']
         if 'support_emergency_delivery' in d:
