@@ -8,9 +8,17 @@ from alipay.aop.api.constant.ParamConstants import *
 class LogisticsInfoDTO(object):
 
     def __init__(self):
+        self._delivery_time = None
         self._delivery_type = None
 
     @property
+    def delivery_time(self):
+        return self._delivery_time
+
+    @delivery_time.setter
+    def delivery_time(self, value):
+        self._delivery_time = value
+    @property
     def delivery_type(self):
         return self._delivery_type
 
@@ -21,6 +29,11 @@ class LogisticsInfoDTO(object):
 
     def to_alipay_dict(self):
         params = dict()
+        if self.delivery_time:
+            if hasattr(self.delivery_time, 'to_alipay_dict'):
+                params['delivery_time'] = self.delivery_time.to_alipay_dict()
+            else:
+                params['delivery_time'] = self.delivery_time
         if self.delivery_type:
             if hasattr(self.delivery_type, 'to_alipay_dict'):
                 params['delivery_type'] = self.delivery_type.to_alipay_dict()
@@ -33,6 +46,8 @@ class LogisticsInfoDTO(object):
         if not d:
             return None
         o = LogisticsInfoDTO()
+        if 'delivery_time' in d:
+            o.delivery_time = d['delivery_time']
         if 'delivery_type' in d:
             o.delivery_type = d['delivery_type']
         return o
