@@ -9,6 +9,7 @@ class ZhimaCreditEpCertificationApplyModel(object):
 
     def __init__(self):
         self._biz_no = None
+        self._device_type = None
 
     @property
     def biz_no(self):
@@ -17,6 +18,13 @@ class ZhimaCreditEpCertificationApplyModel(object):
     @biz_no.setter
     def biz_no(self, value):
         self._biz_no = value
+    @property
+    def device_type(self):
+        return self._device_type
+
+    @device_type.setter
+    def device_type(self, value):
+        self._device_type = value
 
 
     def to_alipay_dict(self):
@@ -26,6 +34,11 @@ class ZhimaCreditEpCertificationApplyModel(object):
                 params['biz_no'] = self.biz_no.to_alipay_dict()
             else:
                 params['biz_no'] = self.biz_no
+        if self.device_type:
+            if hasattr(self.device_type, 'to_alipay_dict'):
+                params['device_type'] = self.device_type.to_alipay_dict()
+            else:
+                params['device_type'] = self.device_type
         return params
 
     @staticmethod
@@ -35,6 +48,8 @@ class ZhimaCreditEpCertificationApplyModel(object):
         o = ZhimaCreditEpCertificationApplyModel()
         if 'biz_no' in d:
             o.biz_no = d['biz_no']
+        if 'device_type' in d:
+            o.device_type = d['device_type']
         return o
 
 
