@@ -9,7 +9,9 @@ class ZhimaCreditPeUserOrderSyncModel(object):
 
     def __init__(self):
         self._buyer_id = None
+        self._credit_biz_order_id = None
         self._open_id = None
+        self._order_amount = None
         self._order_info = None
         self._out_order_no = None
         self._out_request_no = None
@@ -26,6 +28,13 @@ class ZhimaCreditPeUserOrderSyncModel(object):
     def buyer_id(self, value):
         self._buyer_id = value
     @property
+    def credit_biz_order_id(self):
+        return self._credit_biz_order_id
+
+    @credit_biz_order_id.setter
+    def credit_biz_order_id(self, value):
+        self._credit_biz_order_id = value
+    @property
     def open_id(self):
         return self._open_id
 
@@ -33,6 +42,13 @@ class ZhimaCreditPeUserOrderSyncModel(object):
     def open_id(self, value):
         self._open_id = value
     @property
+    def order_amount(self):
+        return self._order_amount
+
+    @order_amount.setter
+    def order_amount(self, value):
+        self._order_amount = value
+    @property
     def order_info(self):
         return self._order_info
 
@@ -90,11 +106,21 @@ class ZhimaCreditPeUserOrderSyncModel(object):
                 params['buyer_id'] = self.buyer_id.to_alipay_dict()
             else:
                 params['buyer_id'] = self.buyer_id
+        if self.credit_biz_order_id:
+            if hasattr(self.credit_biz_order_id, 'to_alipay_dict'):
+                params['credit_biz_order_id'] = self.credit_biz_order_id.to_alipay_dict()
+            else:
+                params['credit_biz_order_id'] = self.credit_biz_order_id
         if self.open_id:
             if hasattr(self.open_id, 'to_alipay_dict'):
                 params['open_id'] = self.open_id.to_alipay_dict()
             else:
                 params['open_id'] = self.open_id
+        if self.order_amount:
+            if hasattr(self.order_amount, 'to_alipay_dict'):
+                params['order_amount'] = self.order_amount.to_alipay_dict()
+            else:
+                params['order_amount'] = self.order_amount
         if self.order_info:
             if hasattr(self.order_info, 'to_alipay_dict'):
                 params['order_info'] = self.order_info.to_alipay_dict()
@@ -139,8 +165,12 @@ class ZhimaCreditPeUserOrderSyncModel(object):
         o = ZhimaCreditPeUserOrderSyncModel()
         if 'buyer_id' in d:
             o.buyer_id = d['buyer_id']
+        if 'credit_biz_order_id' in d:
+            o.credit_biz_order_id = d['credit_biz_order_id']
         if 'open_id' in d:
             o.open_id = d['open_id']
+        if 'order_amount' in d:
+            o.order_amount = d['order_amount']
         if 'order_info' in d:
             o.order_info = d['order_info']
         if 'out_order_no' in d:
