@@ -10,6 +10,8 @@ class AlipayCommerceEcEmployeeInviteQueryResponse(AlipayResponse):
     def __init__(self):
         super(AlipayCommerceEcEmployeeInviteQueryResponse, self).__init__()
         self._enterprise_id = None
+        self._mini_app_sign_url = None
+        self._share_code = None
         self._sign_url = None
 
     @property
@@ -20,6 +22,20 @@ class AlipayCommerceEcEmployeeInviteQueryResponse(AlipayResponse):
     def enterprise_id(self, value):
         self._enterprise_id = value
     @property
+    def mini_app_sign_url(self):
+        return self._mini_app_sign_url
+
+    @mini_app_sign_url.setter
+    def mini_app_sign_url(self, value):
+        self._mini_app_sign_url = value
+    @property
+    def share_code(self):
+        return self._share_code
+
+    @share_code.setter
+    def share_code(self, value):
+        self._share_code = value
+    @property
     def sign_url(self):
         return self._sign_url
 
@@ -31,5 +47,9 @@ class AlipayCommerceEcEmployeeInviteQueryResponse(AlipayResponse):
         response = super(AlipayCommerceEcEmployeeInviteQueryResponse, self).parse_response_content(response_content)
         if 'enterprise_id' in response:
             self.enterprise_id = response['enterprise_id']
+        if 'mini_app_sign_url' in response:
+            self.mini_app_sign_url = response['mini_app_sign_url']
+        if 'share_code' in response:
+            self.share_code = response['share_code']
         if 'sign_url' in response:
             self.sign_url = response['sign_url']
