@@ -11,11 +11,14 @@ class AlipayFundWalletConsultResponse(AlipayResponse):
         super(AlipayFundWalletConsultResponse, self).__init__()
         self._actual_available_amount = None
         self._amount_details = None
+        self._asset_no = None
         self._available_amount = None
         self._error_code = None
         self._error_msg = None
         self._total_amount = None
         self._user_wallet_id = None
+        self._user_wallet_status = None
+        self._wallet_owner_status = None
 
     @property
     def actual_available_amount(self):
@@ -32,6 +35,13 @@ class AlipayFundWalletConsultResponse(AlipayResponse):
     def amount_details(self, value):
         self._amount_details = value
     @property
+    def asset_no(self):
+        return self._asset_no
+
+    @asset_no.setter
+    def asset_no(self, value):
+        self._asset_no = value
+    @property
     def available_amount(self):
         return self._available_amount
 
@@ -66,6 +76,20 @@ class AlipayFundWalletConsultResponse(AlipayResponse):
     @user_wallet_id.setter
     def user_wallet_id(self, value):
         self._user_wallet_id = value
+    @property
+    def user_wallet_status(self):
+        return self._user_wallet_status
+
+    @user_wallet_status.setter
+    def user_wallet_status(self, value):
+        self._user_wallet_status = value
+    @property
+    def wallet_owner_status(self):
+        return self._wallet_owner_status
+
+    @wallet_owner_status.setter
+    def wallet_owner_status(self, value):
+        self._wallet_owner_status = value
 
     def parse_response_content(self, response_content):
         response = super(AlipayFundWalletConsultResponse, self).parse_response_content(response_content)
@@ -73,6 +97,8 @@ class AlipayFundWalletConsultResponse(AlipayResponse):
             self.actual_available_amount = response['actual_available_amount']
         if 'amount_details' in response:
             self.amount_details = response['amount_details']
+        if 'asset_no' in response:
+            self.asset_no = response['asset_no']
         if 'available_amount' in response:
             self.available_amount = response['available_amount']
         if 'error_code' in response:
@@ -83,3 +109,7 @@ class AlipayFundWalletConsultResponse(AlipayResponse):
             self.total_amount = response['total_amount']
         if 'user_wallet_id' in response:
             self.user_wallet_id = response['user_wallet_id']
+        if 'user_wallet_status' in response:
+            self.user_wallet_status = response['user_wallet_status']
+        if 'wallet_owner_status' in response:
+            self.wallet_owner_status = response['wallet_owner_status']
